==> MRAConnector-0.84.tar.bz2: MRAConnector-0.84/core/Smdn.Security.Authentication.Sasl/Smdn.Security.Authentication.Sasl/SaslMechanismAttribute.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2012 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Security.Authentication.Sasl {
  [AttributeUsage(AttributeTargets.Class, AllowMultiple = false, Inherited = false)]
  public sealed class SaslMechanismAttribute : Attribute {
    public string Name {
      get; private set;
    }

    public bool IsPlainText {
      get; private set;
    }

    public SaslMechanismAttribute(string name, bool isPlainText)
    {
      if (name == null)
        throw new ArgumentNullException();
      if (name.Length == 0)
        throw ExceptionUtils.CreateArgumentMustBeNonEmptyString("name");

      Name = name;
      IsPlainText = isPlainText;
    }
  }
}

==> MRAConnector-0.91.tar.bz2: MRAConnector-0.91/core/Smdn.Security.Authentication.Sasl/Smdn.Security.Authentication.Sasl/SaslMechanismAttribute.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2008-2013 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

using System;

namespace Smdn.Security.Authentication.Sasl {
  [AttributeUsage(AttributeTargets.Class, AllowMultiple = false, Inherited = true)]
  public sealed class SaslMechanismAttribute : Attribute {
    public string Name {
      get; private set;
    }

    public bool IsPlainText {
      get; private set;
    }

    internal bool RegisterMechanism {
      get; private set;
    }

    public SaslMechanismAttribute(string name, bool isPlainText)
      : this(name, isPlainText, true)
    {
    }

    internal SaslMechanismAttribute(string name, bool isPlainText, bool registerMechanism)
    {
      if (name == null)
        throw new ArgumentNullException();
      if (name.Length == 0)
        throw ExceptionUtils.CreateArgumentMustBeNonEmptyString("name");

      Name = name;
      IsPlainText = isPlainText;
      RegisterMechanism = registerMechanism;
    }
  }
}
